package com.ibm.ims.dli.types;

import java.io.IOException;
import java.util.Properties;

import com.ibm.ims.dli.DLIErrorMessages;

/**
 * An extensible class provided as a base for user data type converters. The
 * PackedDateConverter class is provided as an example implementation.
 *
 */
public abstract class BaseTypeConverter implements TypeConverter {

	protected Properties properties;

	public final byte[] getUnconvertedBytes(byte[] ioArea, int start, int length) {
		byte[] data = new byte[length];
		System.arraycopy(ioArea, start, data, 0, length);

		return data;
	}

	public final void setUnconvertedBytes(byte[] destIOArea, int start, int length, byte[] value) {
		System.arraycopy(value, 0, destIOArea, start, length);
	}

	// public Object readObject(byte[] ioArea, int start, int length, Class
	// objectType, Collection<String> warningMessages) throws Exception {
	// throw new UnsupportedTypeConversion("Conversion not Implemented");
	// }
	//
	// public void writeObject(byte[] ioArea, int start, int length, Object
	// object, Collection<String> warningMessages) throws Exception {
	// throw new UnsupportedTypeConversion("Conversion not Implemented");
	// }

	public boolean isNull(byte[] ioArea, int offset) throws IOException {
		return false;
	}

	public void setNull(byte[] ioArea, int offset) throws IOException {
		Object[] inserts = { this.getClass().toString() };
		throw new IOException(DLIErrorMessages.getIMSBundle().getString("CONVERTER_NULL_NOT_SUPPORTED", inserts));
	}

	public void setProperties(Properties properties) {
		this.properties = properties;
	}
	/*
	 * public boolean readBoolean(byte[] ioArea, int start, int length) throws
	 * UnsupportedTypeConversion, IOException { throw new
	 * UnsupportedTypeConversion("Conversion not Implemented"); }
	 * 
	 * public void writeBoolean(byte[] ioArea, int start, int length, boolean
	 * value) throws UnsupportedTypeConversion, IOException { throw new
	 * UnsupportedTypeConversion("Conversion not Implemented"); }
	 * 
	 * public char readChar(byte[] ioArea, int start, int length) throws
	 * UnsupportedTypeConversion, IOException { throw new
	 * UnsupportedTypeConversion("Conversion not Implemented"); }
	 * 
	 * public void writeChar(byte[] ioArea, int start, int length, char value)
	 * throws UnsupportedTypeConversion, IOException { throw new
	 * UnsupportedTypeConversion("Conversion not Implemented"); }
	 * 
	 * public byte readByte(byte[] ioArea, int start, int length) throws
	 * UnsupportedTypeConversion, IOException { throw new
	 * UnsupportedTypeConversion("Conversion not Implemented"); }
	 * 
	 * public void writeByte(byte[] ioArea, int start, int length, byte value)
	 * throws UnsupportedTypeConversion, IOException { throw new
	 * UnsupportedTypeConversion("Conversion not Implemented"); }
	 * 
	 * public short readShort(byte[] ioArea, int start, int length) throws
	 * UnsupportedTypeConversion, IOException { throw new
	 * UnsupportedTypeConversion("Conversion not Implemented"); }
	 * 
	 * public void writeShort(byte[] ioArea, int start, int length, short value)
	 * throws UnsupportedTypeConversion, IOException { throw new
	 * UnsupportedTypeConversion("Conversion not Implemented"); }
	 * 
	 * public int readInt(byte[] ioArea, int start, int length) throws
	 * UnsupportedTypeConversion, IOException { throw new
	 * UnsupportedTypeConversion("Conversion not Implemented"); }
	 * 
	 * public void writeInt(byte[] ioArea, int start, int length, int value)
	 * throws UnsupportedTypeConversion, IOException { throw new
	 * UnsupportedTypeConversion("Conversion not Implemented"); }
	 * 
	 * public long readLong(byte[] ioArea, int start, int length) throws
	 * UnsupportedTypeConversion, IOException { throw new
	 * UnsupportedTypeConversion("Conversion not Implemented"); }
	 * 
	 * public void writeLong(byte[] ioArea, int start, int length, long value)
	 * throws UnsupportedTypeConversion, IOException { throw new
	 * UnsupportedTypeConversion("Conversion not Implemented"); }
	 * 
	 * public float readFloat(byte[] ioArea, int start, int length) throws
	 * UnsupportedTypeConversion, IOException { throw new
	 * UnsupportedTypeConversion("Conversion not Implemented"); }
	 * 
	 * public void writeFloat(byte[] ioArea, int start, int length, float value)
	 * throws UnsupportedTypeConversion, IOException { throw new
	 * UnsupportedTypeConversion("Conversion not Implemented"); }
	 * 
	 * public double readDouble(byte[] ioArea, int start, int length) throws
	 * UnsupportedTypeConversion, IOException { throw new
	 * UnsupportedTypeConversion("Conversion not Implemented"); }
	 * 
	 * public void writeDouble(byte[] ioArea, int start, int length, double
	 * value) throws UnsupportedTypeConversion, IOException { throw new
	 * UnsupportedTypeConversion("Conversion not Implemented"); }
	 * 
	 * 
	 * // IEEE 754 Floating point format represents numbers as follows: // seee
	 * eeee | efff ffff | ffff ffff | ffff ffff // where s = sign bit // e =
	 * eponent bit // f = fraction bit // The decimal point is assumed at the
	 * left of the second byte. // When the exponent is non-zero, the MSB of the
	 * second byte is assumed to be // value 1 (2^-1 = 0.5). private final
	 * static int FLOAT_SIGN_MASK = 0x80000000; private final static int
	 * FLOAT_EXPONENT_MASK = 0x7f800000; private final static int
	 * FLOAT_MANTISSA_MASK = 0x007fffff; private final static int
	 * FLOAT_MANTISSA_MSB_MASK = 0x00800000;
	 * 
	 * // The exponent is treated as an unisgned number, giving a range of
	 * 0..255. // A bias of 126 is subtracted from it to give the power used.
	 * private final static int FLOAT_BIAS = 126;
	 * 
	 * // The value of the IEEE Float is then given by mantissa * (2^(exp-126)),
	 * the // sign bit giving the sign
	 * 
	 * // S390 floats have the following format: // seee eee | ffff ffff | ffff
	 * ffff | ffff ffff // The exponent a power of 16, not 2. Hence the best we
	 * can guarantee is that one // of the top four bits of the mantissa are
	 * non-zero - therefore there is no implied // bit as with IEEE // The
	 * exponent has a bias of 64, giving a range of -63..64 private final static
	 * int S390_FLOAT_BIAS = 64; private final static int
	 * S390_FLOAT_EXPONENT_MASK = 0x7f000000; private final static int
	 * S390_FLOAT_MANTISSA_MASK = 0x00ffffff;
	 * 
	 * // IEEE 754 Floating point format represents double precision numbers as
	 * follows: // seee eeee | eeee ffff | ffff ffff | ffff ffff | ...... //
	 * where s = sign bit // e = eponent bit // f = fraction bit // The decimal
	 * point is assumed at the left of the second byte. // When the exponent is
	 * non-zero, the MSB of the second byte is assumed to be // value 1 (2^-1 =
	 * 0.5). private final static long DOUBLE_SIGN_MASK = 0x8000000000000000L;
	 * private final static long DOUBLE_EXPONENT_MASK = 0x7ff0000000000000L;
	 * private final static long DOUBLE_MANTISSA_MASK = 0x000fffffffffffffL;
	 * private final static long DOUBLE_MANTISSA_MSB_MASK = 0x0010000000000000L;
	 * 
	 * // The exponent is treated as an unisgned number // A bias of 1022 is
	 * subtracted from it to give the power used. private final static long
	 * DOUBLE_BIAS = 1022;
	 * 
	 * // The value of the IEEE Float is then given by mantissa *
	 * (2^(exp-1022)), the // sign bit giving the sign
	 * 
	 * // S390 double precision floats have the following format: // seee eee |
	 * ffff ffff | ffff ffff | ffff ffff | .... // The exponent a power of 16,
	 * not 2. Hence the best we can guarantee is that one // of the top four
	 * bits of the mantissa are non-zero - therefore there is no implied // bit
	 * as with IEEE // The exponent has a bias of 64, giving a range of -63..64
	 * private final static int S390_DOUBLE_BIAS = 64; private final static long
	 * S390_DOUBLE_EXPONENT_MASK = 0x7f00000000000000L; private final static
	 * long S390_DOUBLE_MANTISSA_MASK = 0x00ffffffffffffffL;
	 * 
	 * 
	 * // ***************************************************************** //
	 * // Name: convertFromByteToDouble // // Description: Convert the byte
	 * array to a double // // Parameters: sb - a byte array containing a byte
	 * representation of // a double // // Returns: a double // // Cautions:
	 * Assumes byte array is in OS/390 double precision format. // //
	 * ***************************************************************** public
	 * double convertFromByteToDouble(byte[] sb) {
	 * 
	 * long doubleLongBits = convertFromByteToLong(sb); double d =
	 * longS390BitsToDouble (doubleLongBits);
	 * 
	 * return d; } //
	 * ***************************************************************** // //
	 * Name: convertFromByteToFloat // // Description: Convert the byte array to
	 * a float // // Parameters: sb - a byte array containing a byte
	 * representation of // a float // // Returns: a float // // Cautions:
	 * Assumes that bits are in OS/390 single precision format. // //
	 * ***************************************************************** public
	 * float convertFromByteToFloat(byte[] sb) {
	 * 
	 * int floatIntBits = convertFromByteToInt(sb); float f =
	 * intS390BitsToFloat(floatIntBits);
	 * 
	 * return f; } //
	 * ***************************************************************** // //
	 * Name: convertFromByteToInt // // Description: Convert the byte array to
	 * an int // // Parameters: sb - a byte array containing a byte
	 * representation of // a int // // Returns: a int // // Cautions: none //
	 * // *****************************************************************
	 * public int convertFromByteToInt( byte[] sb) { int i = (((int) sb[0]) <<
	 * 24) >>> 0 | (((int) sb[1]) << 24) >>> 8 | (((int) sb[2]) << 24) >>> 16 |
	 * (((int) sb[3]) << 24) >>> 24; return i; } //
	 * ***************************************************************** // //
	 * Name: convertFromByteToLong // // Description: Convert the byte array to
	 * a long // // Parameters: sb - a byte array containing a byte
	 * representation of // a long // // Returns: a long // // Cautions: none //
	 * // *****************************************************************
	 * public long convertFromByteToLong( byte[] sb) {
	 * 
	 * long l = ((((long) sb[0]) << 56) & 0xFF00000000000000L) | ((((long)
	 * sb[1]) << 48) & 0x00FF000000000000L)| ((((long) sb[2]) << 40) &
	 * 0x0000FF0000000000L)| ((((long) sb[3]) << 32) & 0x000000FF00000000L)|
	 * ((((long) sb[4]) << 24) & 0x00000000FF000000L)| ((((long) sb[5]) << 16) &
	 * 0x0000000000FF0000L)| ((((long) sb[6]) << 8) & 0x000000000000FF00L)|
	 * ((((long) sb[7]) ) & 0x00000000000000FFL) ; return l; } //
	 * ***************************************************************** // //
	 * Name: convertToByte // // Description: Returns a byte array
	 * representation of sb // // Parameters: sb - a double // // Returns: byte
	 * array represention of sb in OS/390 double precision format // //
	 * Cautions: none // //
	 * ***************************************************************** public
	 * byte[] convertToByte(double sb) throws DLIException { byte[] tb;
	 * 
	 * long doubleLongBits; doubleLongBits = doubleToS390LongBits(sb); tb =
	 * convertToByte(doubleLongBits);
	 * 
	 * return tb; } //
	 * ***************************************************************** // //
	 * Name: convertToByte // // Description: Returns a byte array
	 * representation of sb // // Parameters: sb - a float // // Returns: byte
	 * array represention of sb in OS/390 single precision format // //
	 * Cautions: none // //
	 * ***************************************************************** public
	 * byte[] convertToByte(float sb) { byte[] tb; int floatIntBits;
	 * 
	 * floatIntBits = floatToS390IntBits(sb); tb = convertToByte(floatIntBits);
	 * 
	 * return tb; } //
	 * ***************************************************************** // //
	 * Name: convertToByte // // Description: Returns a byte array
	 * representation of sb // // Parameters: sb - a long // // Returns: byte
	 * array represention of sb // // Cautions: none // //
	 * ***************************************************************** public
	 * byte[] convertToByte(int sb) {
	 * 
	 * byte[] tb = new byte[4];
	 * 
	 * tb[0] = (byte)(((int)(sb >>> 24)) & 0xFF); tb[1] = (byte)(((int)(sb >>>
	 * 16)) & 0xFF); tb[2] = (byte)(((int)(sb >>> 8)) & 0xFF); tb[3] =
	 * (byte)(((int)(sb >>> 0)) & 0xFF);
	 * 
	 * return tb; } //
	 * ***************************************************************** // //
	 * Name: convertToByte // // Description: Returns a byte array
	 * representation of sb // // Parameters: sb - a long // // Returns: byte
	 * array represention of sb // // Cautions: none // //
	 * ***************************************************************** public
	 * byte[] convertToByte( long sb) { byte[] tb = new byte[8];
	 * 
	 * tb[0] = (byte) ((sb & 0xFF00000000000000L) >>> 56); tb[1] = (byte) ((sb &
	 * 0x00FF000000000000L) >>> 48); tb[2] = (byte) ((sb & 0x0000FF0000000000L)
	 * >>> 40); tb[3] = (byte) ((sb & 0x000000FF00000000L) >>> 32); tb[4] =
	 * (byte) ((sb & 0x00000000FF000000L) >>> 24); tb[5] = (byte) ((sb &
	 * 0x0000000000FF0000L) >>> 16); tb[6] = (byte) ((sb & 0x000000000000FF00L)
	 * >>> 8); tb[7] = (byte) ((sb & 0x00000000000000FFL)); return tb; }
	 * 
	 * private static float intS390BitsToFloat(int floatBits) { //
	 * Trace.entry(clsName,"intS390BitsToFloat"); //
	 * Trace.trace(2,clsName,sccsid); // Trace.trace(2,clsName,
	 * "S390 Bit pattern = " + Integer.toString(floatBits,16));
	 * 
	 * // Test the sign bit (0 = positive, 1 = negative) boolean positive =
	 * ((floatBits & FLOAT_SIGN_MASK) == 0);
	 * 
	 * // Deal with zero straight away... if ((floatBits & 0x7fffffff) == 0) {
	 * // + or - 0.0 // Trace.exit(clsName,"intS390BitsToFloat (zero number)");
	 * if (positive) { return 0.0F; } else { return - (0.0F); } } int mantissa =
	 * floatBits & S390_FLOAT_MANTISSA_MASK; int exponent = floatBits &
	 * S390_FLOAT_EXPONENT_MASK;
	 * 
	 * // move the exponent into the LSB exponent = exponent >> 24; // subtract
	 * the bias exponent = exponent - S390_FLOAT_BIAS;
	 * 
	 * // caculate the IEEE exponent int ieeeExponent = exponent * 4;
	 * 
	 * 
	 * // Normalise the mantissa int ieeeMantissa = mantissa; // Deal with
	 * exponents <= -FLOAT_BIAS if (ieeeExponent <= - (FLOAT_BIAS)) { //
	 * ieeeMantissa is one place to the right since there is no implicit bit set
	 * ieeeMantissa = ieeeMantissa >> 1; // now increase the exponent until it
	 * reaches -FLOAT_BIAS, shifting right one // place at each stage to
	 * compensate while (ieeeExponent < - (FLOAT_BIAS)) { ieeeExponent =
	 * ieeeExponent + 1; ieeeMantissa = ieeeMantissa >> 1; } }
	 * 
	 * // Deal with exponents greater than -FLOAT_BIAS while ((ieeeMantissa !=
	 * 0) && ((ieeeMantissa & FLOAT_MANTISSA_MSB_MASK) == 0) && (ieeeExponent >
	 * - (FLOAT_BIAS))) { ieeeMantissa = ieeeMantissa << 1; // *2 ieeeExponent =
	 * ieeeExponent - 1; // /2 }
	 * 
	 * 
	 * // s390 has a wider range than IEEE, so deal with over and underflows if
	 * (ieeeExponent < -149) { // Trace.exit(clsName,
	 * "intS390BitsToFloat (underflow, returning zero)"); return 0.0F; //
	 * underflow } else if (ieeeExponent > 128) { if (positive) { //
	 * Trace.exit(clsName,"intS390BitsToFloat (overflow, returning +INFINITY)");
	 * return(Float.MAX_VALUE * 2); // + infinity } else { //
	 * Trace.exit(clsName,"intS390BitsToFloat (overflow, returning -INFINITY)");
	 * return - (Float.MAX_VALUE * 2); // -infinity } }
	 * 
	 * 
	 * // Build the IEEE float int ieeeBits = 0; if (!positive) { ieeeBits =
	 * ieeeBits | FLOAT_SIGN_MASK; }
	 * 
	 * // add the bias to the exponent ieeeExponent = ieeeExponent + FLOAT_BIAS;
	 * // move it to the IEEE exponent position ieeeExponent = ieeeExponent <<
	 * 23; // add to the result ieeeBits = ieeeBits | ieeeExponent;
	 * 
	 * // mask the top bit of the mantissa (implicit in IEEE) ieeeMantissa =
	 * ieeeMantissa & FLOAT_MANTISSA_MASK; // add to the result ieeeBits =
	 * ieeeBits | ieeeMantissa;
	 * 
	 * // Trace.trace(2,clsName,"IEEE Bit pattern = " +
	 * Integer.toString(ieeeBits,16)); //
	 * Trace.exit(clsName,"intS390BitsToFloat"); return
	 * Float.intBitsToFloat(ieeeBits); } // To convert from S390 to IEEE we use
	 * the fomula: // m.16^x = m.2^4x, and then normalise by shifting the
	 * mantissa up to three // places left
	 * 
	 * 
	 * private double longS390BitsToDouble(long doubleBits) { //
	 * Trace.entry(clsName,"longS390BitsToDouble"); //
	 * Trace.trace(2,clsName,sccsid); // Trace.trace(2,clsName,
	 * "S390 bit pattern = " + Long.toString(doubleBits,16));
	 * 
	 * // Test the sign bit (0 = positive, 1 = negative) boolean positive =
	 * ((doubleBits & DOUBLE_SIGN_MASK) == 0);
	 * 
	 * // Deal with zero straight away... if ((doubleBits & 0x7fffffffffffffffL)
	 * == 0) { // + or - 0.0 // Trace.exit(clsName,
	 * "longS390BitsToDouble (zero number)");; if (positive) { return 0.0D; }
	 * else { return - (0.0D); } } long mantissa = doubleBits &
	 * S390_DOUBLE_MANTISSA_MASK; long exponent = doubleBits &
	 * S390_DOUBLE_EXPONENT_MASK;
	 * 
	 * // move the exponent into the LSB exponent = exponent >> 56; // subtract
	 * the bias exponent = exponent - S390_DOUBLE_BIAS;
	 * 
	 * // caculate the IEEE exponent long ieeeExponent = exponent * 4;
	 * 
	 * 
	 * // Normalise the mantissa long ieeeMantissa = mantissa; // IEEE mantissa
	 * starts three places right of S390 (+ implicit bit) ieeeMantissa =
	 * ieeeMantissa >> 3; // if this is the samllest possible exponent, then
	 * there is no implicit bit, // and so we need to shift an extra bit if
	 * (ieeeExponent <= - (DOUBLE_BIAS)) { ieeeMantissa = ieeeMantissa >> 1; //
	 * now increase the exponent until it reaches -DOUBLE_BIAS, shifting //
	 * right one place at each stage to compensate while (ieeeExponent < -
	 * (DOUBLE_BIAS)) { ieeeExponent = ieeeExponent + 1; ieeeMantissa =
	 * ieeeMantissa >> 1; } }
	 * 
	 * // complete the normalisation for exponents > -DOUBLE_BIAS while
	 * ((ieeeMantissa != 0) && ((ieeeMantissa & DOUBLE_MANTISSA_MSB_MASK) == 0)
	 * && (ieeeExponent > - (DOUBLE_BIAS))) { ieeeMantissa = ieeeMantissa << 1;
	 * // *2 ieeeExponent = ieeeExponent - 1; // /2 }
	 * 
	 * 
	 * // s390 has a wider range than IEEE, so deal with over and underflows if
	 * (ieeeExponent < -1045) { return 0.0F; // underflow } else if
	 * (ieeeExponent > 1024) { if (positive) { // Trace.trace(1,clsName,
	 * "overflow - returning +INFINITY"); //
	 * Trace.exit(clsName,"longS90BitsToDouble"); return(Double.MAX_VALUE * 2);
	 * // + infinity } else { // Trace.trace(1,clsName,
	 * "overflow - returning -INFINITY"); //
	 * Trace.exit(clsName,"longS390BitsToDouble"); return - (Double.MAX_VALUE *
	 * 2); // -infinity } }
	 * 
	 * 
	 * // Built the IEEE double long ieeeBits = 0; if (!positive) { ieeeBits =
	 * ieeeBits | DOUBLE_SIGN_MASK; }
	 * 
	 * // add the bias to the exponent ieeeExponent = ieeeExponent +
	 * DOUBLE_BIAS; // move it to the IEEE exponent position ieeeExponent =
	 * ieeeExponent << 52; // add to the result ieeeBits = ieeeBits |
	 * ieeeExponent;
	 * 
	 * // mask the top bit of the mantissa (implicit in IEEE) ieeeMantissa =
	 * ieeeMantissa & DOUBLE_MANTISSA_MASK; // add to the result ieeeBits =
	 * ieeeBits | ieeeMantissa;
	 * 
	 * // Trace.trace(2,clsName,"IEEE bit pattern = " +
	 * Long.toString(ieeeBits,16)); //
	 * Trace.exit(clsName,"longS390BitsToDouble"); return
	 * Double.longBitsToDouble(ieeeBits); }
	 * 
	 * // To convert from IEEE to S390 we use the following formula: // let r =
	 * exponent % 4; q = exponent / 4; // if q == 0 then m.2^x = m.16^q // if q
	 * != 0 then m.2^x = (m.2^(r-4)).16^(q+1) for positive q, // =
	 * (m.2^-r).16^q) for negative q private static long
	 * doubleToS390LongBits(double ieeeDouble) throws DLIException { //
	 * Trace.entry(clsName,"doubleToS390LongBits"); //
	 * Trace.trace(2,clsName,sccsid);
	 * 
	 * // Get the bit pattern long ieeeLongBits =
	 * Double.doubleToLongBits(ieeeDouble); // Trace.trace(2,clsName,
	 * "IEEE double bit pattern= " + Long.toString(ieeeLongBits,16));
	 * 
	 * // Test the sign bit (0 = positive, 1 = negative) boolean positive =
	 * ((ieeeLongBits & DOUBLE_SIGN_MASK) == 0);
	 * 
	 * // Deal with zero straight away... if ((ieeeLongBits &
	 * 0x7fffffffffffffffL) == 0) { // + or - 0.0 // Trace.exit(clsName,
	 * "doubleToS390LongBits (zero number)"); return ieeeLongBits; }
	 * 
	 * 
	 * // Extract the exponent long exponent = ieeeLongBits &
	 * DOUBLE_EXPONENT_MASK; // shift right 52 bits to get exponent in least
	 * significant byte exponent = exponent >>> 52; // subtract the bias to get
	 * the true value exponent = exponent - DOUBLE_BIAS;
	 * 
	 * // Extract the mantissa long mantissa = ieeeLongBits &
	 * DOUBLE_MANTISSA_MASK;
	 * 
	 * // Now begin the conversion to S390
	 * 
	 * long remainder = Math.abs(exponent) % 4; long quotient =
	 * Math.abs(exponent) / 4; long s390Exponent = quotient; if ((exponent > 0)
	 * && (remainder != 0)) { s390Exponent = s390Exponent + 1; }
	 * 
	 * // put the sign back in if (exponent < 0) { s390Exponent = -s390Exponent;
	 * }
	 * 
	 * // Add the bias s390Exponent += S390_DOUBLE_BIAS;
	 * 
	 * // Now adjust the mantissa part long s390Mantissa = mantissa; // for an
	 * exponent greater than -DOUBLE_BIAS, add in the implicit bit if (exponent
	 * > (-DOUBLE_BIAS)) { s390Mantissa = s390Mantissa |
	 * DOUBLE_MANTISSA_MSB_MASK; } else { // there is no implicit bit, so the
	 * mantissa is one bit to the right of what // we would normally expect. We
	 * need to fix this for S390 s390Mantissa = s390Mantissa << 1; }
	 * 
	 * // S390 Mantissa starts 4 bits left of ieee one. The first of these is
	 * implied in // IEEE so only shift 3 places s390Mantissa = s390Mantissa <<
	 * 3; if (remainder > 0) { if (exponent > 0) { // the next two lines perform
	 * the (m.2^(r-4)) part of the conversion int shift_places = (int) (4 -
	 * remainder); s390Mantissa = s390Mantissa >>> shift_places; } else { // to
	 * avoid loss of precision when the exponent is at a minimum, // we may need
	 * to shift the mantissa four places left and decrease the // s390 exponent
	 * by one before shifting right if ((exponent == - (DOUBLE_BIAS)) &&
	 * ((s390Mantissa & 0x00f0000000000000L) == 0)) { s390Mantissa =
	 * s390Mantissa << 4; s390Exponent = s390Exponent - 1; } // the next two
	 * lines perform the m.2-r part of the conversion s390Mantissa =
	 * s390Mantissa >>> remainder; } }
	 * 
	 * 
	 * // An exponent of -DOUBLE_BIAS is the smallest that IEEE can do. S390 has
	 * // a wider range, and hence may be able to normalise the mantissa more
	 * than // is possible for IEEE // Each shift left of four bits is
	 * equivalent to multiplying by 16, // so the exponent must be reduced by 1
	 * if (exponent == - (DOUBLE_BIAS)) { while ((s390Mantissa != 0) &&
	 * ((s390Mantissa & 0x00f0000000000000L) == 0)) { s390Mantissa =
	 * s390Mantissa << 4; s390Exponent = s390Exponent - 1; } }
	 * 
	 * // if the exponent is now > 127, we have an overflow since IEEE can
	 * handle larger numbers // than S390 can. if (s390Exponent > 127) { //
	 * Trace.trace(1,clsName,"Exponent = " + s390Exponent); //
	 * Trace.exit(clsName,"doubleToS390LongBits (exponent outside of range)");
	 * throw new DLIException(DLIErrorMessages.getIMSBundle().getString(
	 * "NUMBER_OUT_OF_RANGE")); //throw new IOException(
	 * "Number outside of range for double precision S/390 Float"); } else if
	 * (s390Exponent < 0) { // the number is too small to represent, set it to
	 * zero // Trace.trace(1,clsName,
	 * "Number too small to represent, rounding to zero"); //
	 * Trace.exit(clsName,"doubleToS390LongBits (exponent outside of range)");
	 * return 0L; }
	 * 
	 * 
	 * // Assemble the s390BitPattern long s390Double = 0L; long
	 * s390ExponentBits = s390Exponent & 0x000000000000007FL; // make sure we
	 * only deal with 7 bits // add the exponent s390Double = s390ExponentBits
	 * << 56; // shift to MSB // add the sign if (!positive) { s390Double =
	 * s390Double | DOUBLE_SIGN_MASK; } // add the mantissa s390Double =
	 * s390Double | s390Mantissa;
	 * 
	 * // Trace.trace(2,clsName,"S390 bit pattern = " +
	 * Long.toString(s390Double,16)); //
	 * Trace.exit(clsName,"doubleToS390LongBits"); return s390Double; } // To
	 * convert from IEEE to S390 we use the following formula: // let r =
	 * exponent % 4; q = exponent / 4; // if q == 0 then m.2^x = m.16^q // if q
	 * != 0 then m.2^x = (m.2^(r-4)).16^(q+1) for positive q, // =
	 * (m.2^-r).16^q) for negative q
	 * 
	 * private static int floatToS390IntBits(float ieeeFloat) { //
	 * Trace.entry(clsName,"floatToS390IntBits"); //
	 * Trace.trace(2,clsName,sccsid);
	 * 
	 * // Get the bit pattern int ieeeIntBits = Float.floatToIntBits(ieeeFloat);
	 * // Trace.trace(2,clsName,"IEEE bit pattern = " +
	 * Integer.toString(ieeeIntBits,16));
	 * 
	 * // Test the sign bit (0 = positive, 1 = negative) boolean positive =
	 * ((ieeeIntBits & FLOAT_SIGN_MASK) == 0);
	 * 
	 * // Deal with zero straight away... if ((ieeeIntBits & 0x7fffffff) == 0) {
	 * // + or - 0.0 // Trace.exit(clsName,"floatToS390IntBits (zero number)");
	 * return ieeeIntBits; }
	 * 
	 * 
	 * // Extract the exponent int exponent = ieeeIntBits & FLOAT_EXPONENT_MASK;
	 * // shift right 23 bits to get exponent in least significant byte exponent
	 * = exponent >>> 23; // subtract the bias to get the true value exponent =
	 * exponent - FLOAT_BIAS;
	 * 
	 * // Extract the mantissa int mantissa = ieeeIntBits & FLOAT_MANTISSA_MASK;
	 * // for an exponent greater than -FLOAT_BIAS, add in the implicit bit if
	 * (exponent > (-FLOAT_BIAS)) { mantissa = mantissa |
	 * FLOAT_MANTISSA_MSB_MASK; }
	 * 
	 * // Now begin the conversion to S390
	 * 
	 * int remainder = Math.abs(exponent) % 4; int quotient = Math.abs(exponent)
	 * / 4; int s390Exponent = quotient; if ((exponent > 0) && (remainder != 0))
	 * { s390Exponent = s390Exponent + 1; }
	 * 
	 * // put the sign back in if (exponent < 0) { s390Exponent = -s390Exponent;
	 * }
	 * 
	 * // Add the bias s390Exponent += S390_FLOAT_BIAS;
	 * 
	 * // Now adjust the mantissa part int s390Mantissa = mantissa; if
	 * (remainder > 0) { if (exponent > 0) { // the next two lines perform the
	 * (m.2^(r-4)) part of the conversion int shift_places = 4 - remainder;
	 * s390Mantissa = s390Mantissa >>> shift_places; } else { // to avoid loss
	 * of precision when the exponent is at a minimum, // we may need to shift
	 * the mantissa four places left, and decrease the // s390Exponent by one
	 * before shifting right if ((exponent == - (FLOAT_BIAS)) && ((s390Mantissa
	 * & 0x00f00000) == 0)) { s390Mantissa = s390Mantissa << 4; s390Exponent =
	 * s390Exponent - 1; } // the next two line perform the (m.2^-r) part of the
	 * conversion int shift_places = remainder; s390Mantissa = s390Mantissa >>>
	 * shift_places; } }
	 * 
	 * 
	 * // An exponent of -FLOAT_BIAS is the smallest that IEEE can do. S390 has
	 * // a wider range, and hence may be able to normalise the mantissa more
	 * than // is possible for IEEE // Also, since an exponent of -FLOAT_BIAS
	 * has no implicit bit set, the mantissa // starts with a value of 2^-1 at
	 * the second bit of the second byte. We thus need // to shift one place
	 * left to move the mantissa to the S390 position // Follwoing that, we
	 * notmalise as follows: // Each shift left of four bits is equivalent to
	 * multiplying by 16, // so the exponent must be reduced by 1 if (exponent
	 * == - (FLOAT_BIAS)) { s390Mantissa = s390Mantissa << 1; while
	 * ((s390Mantissa != 0) && ((s390Mantissa & 0x00f00000) == 0)) {
	 * s390Mantissa = s390Mantissa << 4; s390Exponent = s390Exponent - 1; } }
	 * 
	 * // Assemble the s390BitPattern int s390Float = 0; int s390ExponentBits =
	 * s390Exponent & 0x0000007F; // make sure we only deal with 7 bits // add
	 * the exponent s390Float = s390ExponentBits << 24; // shift to MSB // add
	 * the sign if (!positive) { s390Float = s390Float | FLOAT_SIGN_MASK; } //
	 * add the mantissa s390Float = s390Float | s390Mantissa;
	 * 
	 * // Trace.trace(2,clsName,"S390 Bit pattern = " +
	 * Integer.toString(s390Float,16)); //
	 * Trace.exit(clsName,"floatToS390IntBits"); return s390Float; }
	 */

}